diff lwasm/lwasm.h @ 333:507f442dc71e

Add support for 6800 compatibility instructions. The occasional program uses the 6800 compatibility instructions since they are actually specified by Motorola in at least some documentation. They advertised the 6809 as source compatible with the 6800. This mode is not enabled by default, however. It is my belief that receiving an error when using a non-6809 instruction is more useful since it is unlikely that much 6800 source code is being assembled for the 6809 these days. Nevertheless, the --6809compat option is present for just those purposes so one does not have to resort to using macros (which would work equally well in most cases).
author William Astle <lost@l-w.ca>
date Tue, 15 Apr 2014 10:57:34 -0600
parents d4ac484d0ec6
children 30b2bad9b5eb
line wrap: on
line diff
--- a/lwasm/lwasm.h	Mon Apr 14 07:43:43 2014 -0600
+++ b/lwasm/lwasm.h	Tue Apr 15 10:57:34 2014 -0600
@@ -89,7 +89,8 @@
 	PRAGMA_AUTOBRANCHLENGTH = 0x0100,	// automatically select proper length for relative branches
 	PRAGMA_EXPORT = 0x0200,				// export symbols by default, unless local
 	PRAGMA_SYMBOLNOCASE = 0x400,		// symbols defined under this pragma are matched case insensitively
-	PRAGMA_CONDUNDEFZERO = 0x800		// treat undefined symbols as zero in conditionals during pass 1
+	PRAGMA_CONDUNDEFZERO = 0x800,		// treat undefined symbols as zero in conditionals during pass 1
+	PRAGMA_6800COMPAT = 0x1000			// enable 6800 compatibility opcodes
 };